@@ -1,28 +1,29 @@
-#--
-#Copyright 2007 Nominet UK
-#
-#Licensed under the Apache License, Version 2.0 (the "License");
-#you may not use this file except in compliance with the License.
-#You may obtain a copy of the License at
-#
+# --
+# Copyright 2007 Nominet UK
+# 
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+# 
 #     http://www.apache.org/licenses/LICENSE-2.0
-#
-#Unless required by applicable law or agreed to in writing, software
-#distributed under the License is distributed on an "AS IS" BASIS,
-#WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-#See the License for the specific language governing permissions and
-#limitations under the License.
-#++
+# 
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+# ++
 
-require 'test/unit'
-require 'dnsruby'
+require_relative 'spec_helper'
 
-class Nsec3Test < Test::Unit::TestCase
-  INPUT = "2t7b4g4vsa5smi47k61mv5bv1a22bojr.example. 3600 IN NSEC3 1 1 12 aabbccdd ( " + 
+class Nsec3Test < Minitest::Test
+
+  include Dnsruby
+
+  INPUT = "2t7b4g4vsa5smi47k61mv5bv1a22bojr.example. 3600 IN NSEC3 1 1 12 aabbccdd ( " +
     "2vptu5timamqttgl4luu9kg21e0aor3s A RRSIG )"
   INPUT2 = "2t7b4g4vsa5smi47k61mv5bv1a22bojr.example. 3600 IN NSEC3 1 1 12 aabbccdd " +
     "2vptu5timamqttgl4luu9kg21e0aor3s"
-  include Dnsruby
   def test_nsec_from_string
     nsec = Dnsruby::RR.create(INPUT)
 #    assert_equal(H("x.y.w.example"), nsec.next_hashed.to_s)
@@ -31,7 +32,7 @@ class Nsec3Test < Test::Unit::TestCase
     assert_equal(12, nsec.iterations)
     assert_equal("aabbccdd", nsec.salt)
     assert_equal(Dnsruby::Nsec3HashAlgorithms.SHA_1, nsec.hash_alg)
-    
+
     nsec2 = Dnsruby::RR.create(nsec.to_s)
     assert(nsec2.to_s == nsec.to_s)
 
@@ -90,7 +91,7 @@ class Nsec3Test < Test::Unit::TestCase
       c = Dnsruby::RR::NSEC3.calculate_hash(name, 12, Dnsruby::RR::NSEC3.decode_salt("aabbccdd"), 1)
       assert_equal(c, hash, "Expected #{hash} but got #{c} for #{name}")
     }
-    #
+    # 
   end
 
   def test_nsec_other_stuff
@@ -105,7 +106,7 @@ class Nsec3Test < Test::Unit::TestCase
 #      fail
 #    rescue DecodeError
 #    end
-    # Be liberal in what you accept...
+    #  Be liberal in what you accept...
 #    begin
 #      nsec.hash_alg = 8
 #      fail
@@ -117,10 +118,10 @@ class Nsec3Test < Test::Unit::TestCase
     rescue DecodeError
     end
   end
-  
+
   def test_nsec_types
-    # Test types in last section to 65536.
-    #Test no zeros
+    #  Test types in last section to 65536.
+    # Test no zeros
     nsec = Dnsruby::RR.create(INPUT)
     nsec.add_type(Types.TYPE65534)
     assert(nsec.types.include?(Types.TYPE65534))
@@ -135,9 +136,4 @@ class Nsec3Test < Test::Unit::TestCase
      rr = RR.create("929p027vb26s89h6fv5j7hmsis4tcr1p.tjeb.nl.		 3600		 IN		 NSEC3		 1 0 5 beef  9rs4nbe7128ap5i6v196ge2iag5b7rcq A AAAA RRSIG
        ")
   end
-
-  def test_rfc_examples
-    print "IMPLEMENT NSEC3 validation!\n"
-    return
-  end
 end
\ No newline at end of file
