@@ -1,27 +1,26 @@
-#--
-#Copyright 2007 Nominet UK
-#
-#Licensed under the Apache License, Version 2.0 (the "License");
-#you may not use this file except in compliance with the License.
-#You may obtain a copy of the License at
-#
+# --
+# Copyright 2007 Nominet UK
+# 
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+# 
 #     http://www.apache.org/licenses/LICENSE-2.0
-#
-#Unless required by applicable law or agreed to in writing, software
-#distributed under the License is distributed on an "AS IS" BASIS,
-#WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-#See the License for the specific language governing permissions and
-#limitations under the License.
-#++
+# 
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+# ++
 
-require 'test/unit'
-require 'dnsruby'
+require_relative 'spec_helper'
 
-class RrsetTest < Test::Unit::TestCase
+class RrsetTest < Minitest::Test
   def test_rrset
     rrset = Dnsruby::RRSet.new
 
-      
+
     rr=Dnsruby::RR.create({	   :name => "example.com",
         :ttl  => 3600,
         :type         => 'MX',
@@ -34,18 +33,18 @@ class RrsetTest < Test::Unit::TestCase
     rrset.add(rr)
     rr.preference = 1
     rrset.add(rr)
-    
+
     canon = rrset.sort_canonical
-    
+
     assert(1 == canon[0].preference)
     assert(10 == canon[1].preference)
     assert(12 == canon[2].preference)
-    
+
     assert(rrset.sigs.length == 0)
     assert(rrset.num_sigs == 0)
     assert(rrset.rrs.length == 3)
 
-    # Check RRSIG records (only of the right type) can be added to the RRSet
+    #  Check RRSIG records (only of the right type) can be added to the RRSet
     sig = Dnsruby::RR.create({:name=>"example.com",         :ttl  => 3600,
         :type         => 'RRSIG',
         :type_covered  => 'A',
